
;********************************************************************************
;* getLine:
;*	Read in a line of text with simple editing
;*
;* (Simple) Editing:
;*	Backspace or DEL: Delete char to left of cursor
;*	Ctrl-C:           Delete whole line
;*
;* Entry:
;*	Acc has the prompt character.
;*
;* Exit:
;*	Data stored at lineInput with a terminating CR.
;********************************************************************************

;********************************************************************************
;* This file is part of gibl:							*
;*	Gordons Interactive Basic Language                                      *
;********************************************************************************
;*    A Tiny Basic for the 6502 inspired by the NIBL Tiny Basic interpreter;	*
;*    "National Industrial Basic Language" originally for the INS8060 SC/MP	*
;*    system.									*
;*										*
;*    gibl is distributed under a "Source Available" license.			*
;*	It is NOT Open source and must not be treated as such.			*
;*										*
;*    See the file LICENSE for details.						*
;*										*
;*    gibl is Copyright (c) 2023 by Gordon Henderson				*
;********************************************************************************

	.include	"keys.h"

.proc	getLine
	sta	temp0		; Save prompt

getLine0:
	lda	temp0		; Output prompt:
	jsr	putChar
	lda	#0		; Zero length
	sta	iLen

getLineLoop:
	jsr	getChar
	cmp	#KEY_CTRL_C		; Or Ctrl-C
	bne	:+

; Cancel the line

	jsr	putStr
	.byte	"\",13,10,0
	jmp	getLine0

; Other control character?

:	cmp	#KEY_BS			; Backspace?
	bne	notBackSp

doBackSp:
	lda	iLen
	beq	getLineLoop		; Already at the start?
	jsr	putStr
	.byte	KEY_BS,' ',KEY_BS,0	; Backspace, space, backspace..
	dec	iLen
	jmp	getLineLoop

notBackSp:
	cmp	#KEY_DEL		; DELete?
	beq	doBackSp
	bge	getLineLoop		; Ignore characters > 127

	cmp	#KEY_CR
	beq	return

	cmp	#KEY_NL
	beq	return

	cmp	#KEY_SPACE
	blt	getLineLoop		; Ignore all other control characters

	jmp	printable


;********************************************************************************
;* return:
;*	Ctrl-M, or Ctrl-J
;*	Terminate and return the line
;********************************************************************************

return:
	ldy	iLen		; Store CR
	lda	#KEY_CR		; In-case we got here from a newline
	sta	lineInput,y
	jsr	newLine		; Take a newline

; Check for some specific OS commands before we hand back to BASIC

	jsr	rubyCommandCheck
	beq	getLine0
	rts



;********************************************************************************
; Ordinary printable character
;********************************************************************************

printable:

	ldy	iLen		; Buffer full?
	cpy	#maxLen-1
	bne	:+
	beq	getLineLoop
:

; Print and store key

	sta	lineInput,y
	jsr	putChar
	inc	iLen
	jmp	getLineLoop

.endproc
