
;********************************************************************************
;* oswordGetLine.s:
;*	Read in a line of text.
;*	Here, we just called OSWORD 0.
;*	The RubyOS version handles editing and history recall.
;*
;*	To remain faithful to the TinyBasic/NIBL one, you need to implement
;*	a bare minimal of editor, remeber it was intended to run on a teletype
;*	in the first instance.
;*
;*	osword 0 will return with Y = to the number of characters typed, so
;*	Y = 0 will be a CR.
;*	Carry is set if the input was terminated by ESC.
;*
;* NOTE: The maximum input line length must be < 127 characters long. Some tests
;*	look for the counter going negative.
;********************************************************************************

;********************************************************************************
;* This file is part of gibl:							*
;*	Gordons Interactive Basic Language                                      *
;********************************************************************************
;*    A Tiny Basic for the 6502 inspired by the NIBL Tiny Basic interpreter;	*
;*    "National Industrial Basic Language" originally for the INS8060 SC/MP	*
;*    system.									*
;*										*
;*    gibl is distributed under a "Source Available" license.			*
;*	It is NOT Open source and must not be treated as such.			*
;*										*
;*    See the file LICENSE for details.						*
;*										*
;*    gibl is Copyright (c) 2023 by Gordon Henderson				*
;********************************************************************************


.proc	getLine

; Save prompt

	sta	temp0

getLine0:

; Output prompt:

	lda	temp0
	jsr	putChar

	ldx	#<getLineData
	ldy	#>getLineData
	lda	#0
	jsr	osWord

; Check for some specific OS commands before we hand back to BASIC

	jsr	rubyCommandCheck
	beq	getLine0
	rts

getLineData:
		.word	lineInput		; Address of input buffer
		.byte	maxLen			; Max length
		.byte	32			; Smallest value to accept
		.byte	126			; largest...
.endproc
